@@ -1,40 +1,22 @@
 /* -*- C++ -*-
+    This file is part of ThreadWeaver.
 
-   This file is part of ThreadWeaver.
+    SPDX-FileCopyrightText: 2005-2014 Mirko Boehm <mirko@kde.org>
 
-   Author: Mirko Boehm
-   Copyright: (C) 2005-2014 Mirko Boehm
-   Contact: mirko@kde.org
-         http://www.kde.org
-         http://creative-destruction.me
-
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef MODEL_H
 #define MODEL_H
 
 #include <QAbstractListModel>
-#include <QVector>
 #include <QFileInfoList>
+#include <QVector>
 
 #include <ThreadWeaver/ResourceRestrictionPolicy>
 
-#include "Progress.h"
 #include "Image.h"
+#include "Progress.h"
 
 class Model : public QAbstractListModel
 {
@@ -43,7 +25,7 @@ public:
     enum Roles {
         Role_SortRole = Qt::UserRole,
         Role_ImageRole,
-        Role_StepRole
+        Role_StepRole,
     };
 
     explicit Model(QObject *parent = nullptr);
@@ -61,11 +43,11 @@ public:
     void setSaveThumbNailCap(int cap);
 
     void clear();
-    void prepareConversions(const QFileInfoList& filenames, const QString& outputDirectory);
+    void prepareConversions(const QFileInfoList &filenames, const QString &outputDirectory);
     bool computeThumbNailsBlockingInLoop();
     bool computeThumbNailsBlockingConcurrent();
 
-    void queueUpConversion(const QStringList& files, const QString& outputDirectory);
+    void queueUpConversion(const QStringList &files, const QString &outputDirectory);
     Progress progress() const;
     void progressChanged();
     void elementChanged(int id);
@@ -76,7 +58,7 @@ public:
 
 Q_SIGNALS:
     void completed();
-    void progress(int, int);
+    void progressStepChanged(int, int);
     void signalElementChanged(int);
 
 private Q_SLOTS:
