@@ -10,15 +10,15 @@
 
 #include "thread.h"
 
+#include <QCoreApplication>
 #include <QDebug>
 #include <QPointer>
-#include <QCoreApplication>
 
-#include "threadweaver.h"
-#include "weaver.h"
-#include "job.h"
 #include "debuggingaids.h"
 #include "exception.h"
+#include "job.h"
+#include "threadweaver.h"
+#include "weaver.h"
 
 using namespace ThreadWeaver;
 
@@ -49,10 +49,9 @@ Thread::Thread(Weaver *parent)
     : QThread() // no parent, because the QObject hierarchy of this thread
     // does not have a parent (see QObject::pushToThread)
     , d(new Private(parent))
- {
-    const QString queueName = parent->objectName().isEmpty()
-            ? QString::fromLatin1("Queue(0x%1)").arg(quintptr(parent), 0, 16, QChar::fromLatin1('0'))
-            : parent->objectName();
+{
+    const QString queueName =
+        parent->objectName().isEmpty() ? QString::fromLatin1("Queue(0x%1)").arg(quintptr(parent), 0, 16, QChar::fromLatin1('0')) : parent->objectName();
     setObjectName(QString::fromLatin1("%1[%2]").arg(queueName).arg(QString::number(id()), 2, QChar::fromLatin1('0')));
 }
 
@@ -63,7 +62,7 @@ Thread::~Thread()
 
 unsigned int Thread::id() const
 {
-    return d->id; //id is const
+    return d->id; // id is const
 }
 
 void Thread::run()
@@ -72,7 +71,10 @@ void Thread::run()
     Q_ASSERT(QCoreApplication::instance() != nullptr);
     d->parent->threadEnteredRun(this);
 
-    emit started(this);
+#if THREADWEAVER_BUILD_DEPRECATED_SINCE(5, 80)
+    Q_EMIT started(this);
+#endif
+
     TWDEBUG(3, "Thread::run [%u]: running.\n", id());
 
     bool wasBusy = false;
@@ -82,21 +84,23 @@ void Thread::run()
         try {
             // the assignment is intentional: newJob needs to go out of scope at the end of the if statement
             if (JobPointer newJob = d->parent->applyForWork(this, wasBusy)) {
-                QMutexLocker l(&d->mutex); Q_UNUSED(l);
+                QMutexLocker l(&d->mutex);
+                Q_UNUSED(l);
                 d->job = newJob;
             } else {
                 break;
             }
-        } catch (AbortThread&) {
+        } catch (AbortThread &) {
             break;
         }
 
         wasBusy = true;
         d->job->execute(d->job, this);
         JobPointer oldJob;
-        {   // When finally destroying the last reference to d->job, do not hold the mutex.
+        { // When finally destroying the last reference to d->job, do not hold the mutex.
             // It may trigger destruction of the job, which can execute arbitrary code.
-            QMutexLocker l(&d->mutex); Q_UNUSED(l);
+            QMutexLocker l(&d->mutex);
+            Q_UNUSED(l);
             oldJob = d->job;
             d->job.clear();
         }
@@ -107,9 +111,9 @@ void Thread::run()
 
 void Thread::requestAbort()
 {
-    QMutexLocker l(&d->mutex); Q_UNUSED(l);
+    QMutexLocker l(&d->mutex);
+    Q_UNUSED(l);
     if (d->job) {
         d->job->requestAbort();
     }
 }
-
